import { defineNuxtModule } from '@nuxt/kit';
import * as underscore from 'underscore';

const module = defineNuxtModule({
  meta: {
    name: "nuxt-underscore",
    configKey: "underscore",
    compatibility: {
      nuxt: "^3.0.0"
    }
  },
  defaults: {
    prefix: "use",
    prefixSkip: ["is"],
    exclude: [],
    alias: []
  },
  setup(options, nuxt) {
    const imports = [];
    const prefix = options.prefix || "";
    const aliasMap = new Map(options.alias);
    const exludes = [...options.exclude];
    for (const [name] of Object.entries(underscore)) {
      if (!exludes.includes(name)) {
        const alias = aliasMap.has(name) ? aliasMap.get(name) : name;
        const as = (() => {
          const isPrefix = !options.prefixSkip.some((key) => alias.startsWith(key)) && prefix;
          return isPrefix ? prefix + alias.replace(/^[a-z]/g, function(val) {
            return val.toUpperCase();
          }) : alias;
        })();
        imports.push({ name, as });
      }
    }
    nuxt.hook("vite:extend", ({ config }) => {
      var _a;
      config.optimizeDeps || (config.optimizeDeps = {});
      (_a = config.optimizeDeps).exclude || (_a.exclude = []);
      config.optimizeDeps.exclude.push("underscore");
    });
    nuxt.hook("autoImports:sources", (sources) => {
      if (!sources.some((i) => i.from === "underscore")) {
        sources.push({ imports, from: "underscore" });
      }
    });
  }
});

export { module as default };
